# bvqpy

## Overview

This package contains data from a Barcelona Vocabulary Questionnaire (BVQ), a vocabulary checklist aimed at to assessing lexical development in toddlers growing up in Catalan-Spanish bilingual environments. The questionnaire was deployed using [formr](https://formr.org/), and the materials used to generate the items are available in the GitHub repository.

This package also contains multiple functions that extract the data and generate many metrics used frequently in the language acquisition literature to examine participants’ vocabulary or to consult acquisition norms of particular words. Documentation and working examples are available in the [package website](https://gongcastro.github.io/bvq).


## Installation

Using pip:

```python
pip install bvqpy
```

## Data accesibility

BVQ is currently a developing package for internal use at the [Center for Brain and Cognititon](https://www.upf.edu/web/cbc) (CBC). For this reason, logging in requires a password that can be required by writing to the maintainer of this package ([gongarciacastro@gmail.com](mailto:gongarciacastro@gmail.com)).

## Code of Conduct

Please note that the bvq project is released with a [Contributor Code of Conduct](https://contributor-covenant.org/version/2/1/CODE_OF_CONDUCT.html). By contributing to this project, you agree to abide by its terms.
